@@ -1,4 +1,4 @@
-# Copyright 2016-2021 The Van Valen Lab at the California Institute of
+# Copyright 2016-2022 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -40,11 +40,13 @@ from deepcell.applications import Application
 
 
 MODEL_PATH = ('https://deepcell-data.s3-us-west-1.amazonaws.com/'
-              'saved-models/TrackingModel-6.tar.gz')
+              'saved-models/NuclearTrackingInf-6.tar.gz')
+MODEL_HASH = 'ac1323bfc331979464c8fbabaf6d55b2'
 
 
 ENCODER_PATH = ('https://deepcell-data.s3-us-west-1.amazonaws.com/'
-                'saved-models/TrackingModelNE-4.tar.gz')
+                'saved-models/NuclearTrackingNE-6.tar.gz')
+ENCODER_HASH = '29f668823680d10ac0af5c559b5174f1'
 
 
 class CellTracking(Application):
@@ -87,7 +89,7 @@ class CellTracking(Application):
                  distance_threshold=64,
                  birth=0.99,
                  death=0.99,
-                 division=0.9,
+                 division=0.01,
                  track_length=8,
                  embedding_axis=0):
         self.neighborhood_encoder = neighborhood_encoder
@@ -101,7 +103,7 @@ class CellTracking(Application):
         if self.neighborhood_encoder is None:
             archive_path = tf.keras.utils.get_file(
                 'NuclearTrackingNE.tgz', ENCODER_PATH,
-                file_hash='f73f84ada41dec266c848bd80e817e01',
+                file_hash=ENCODER_HASH,
                 extract=True, cache_subdir='models')
             model_path = os.path.splitext(archive_path)[0]
             self.neighborhood_encoder = tf.keras.models.load_model(model_path)
@@ -109,7 +111,7 @@ class CellTracking(Application):
         if model is None:
             archive_path = tf.keras.utils.get_file(
                 'NuclearTrackingInf.tgz', MODEL_PATH,
-                file_hash='d310702b094674cb699775820a2a150c',
+                file_hash=MODEL_HASH,
                 extract=True, cache_subdir='models')
             model_path = os.path.splitext(archive_path)[0]
             model = tf.keras.models.load_model(model_path)
